package np.com.sarbagyastha.flutter_clipboard

import android.annotation.TargetApi
import android.content.ClipData
import android.content.ClipboardManager
import android.content.Context
import android.os.Build
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import io.flutter.plugin.common.PluginRegistry.Registrar


class FlutterClipboardPlugin(private val registrar: Registrar) : MethodCallHandler {

    private lateinit var clipboardManager: ClipboardManager
    private lateinit var context: Context

    companion object {
        @JvmStatic
        fun registerWith(registrar: Registrar) {
            val channel = MethodChannel(registrar.messenger(), "sarbagyastha.com.np/clipboard")
            channel.setMethodCallHandler(FlutterClipboardPlugin(registrar))
        }
    }

    @TargetApi(Build.VERSION_CODES.HONEYCOMB)
    override fun onMethodCall(call: MethodCall, result: Result) {
        if (registrar.activity() != null) {
            context = registrar.activity()
        } else {
            context = registrar.context()
        }
        clipboardManager = context.getSystemService(Context.CLIPBOARD_SERVICE) as ClipboardManager
        when (call.method) {
            "retrieveClipboard" -> {
                if (clipboardManager.primaryClip?.itemCount!! > 0)
                    result.success(clipboardManager.primaryClip?.getItemAt(0)?.text.toString())
            }
            "copyToClipboard" -> {
                val clip = ClipData.newPlainText("text", call.arguments.toString())
                clipboardManager.primaryClip = clip
                result.success(clip.itemCount > 0)
            }
            else -> result.notImplemented()
        }
    }
}
